netapp_ontap.models.fc_port_transceiver API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.fc_port_transceiver`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class FcPortTransceiverSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the FcPortTransceiver object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `capabilities GET`

    The speeds of which the transceiver is capable in gigabits per second.

  `form_factor GET`

    The form factor of the transceiver. Possible values are: - sfp - Small Form Factor - Pluggable - sff - Small Form Factor - unknown - Unknown

    Valid choices:

    - sfp
    - sff
    - unknown
  `manufacturer GET`

    The manufacturer of the transceiver.

    Example: Acme, Inc.

  `part_number GET`

    The part number of the transceiver.